<template>
    <div class="system-add-dept-container">
        <el-dialog :title="title" v-model="isShowDialog" width="600px">
            <el-form :model="departmentForm" size="default" ref="depRef" :rules="depFormRules" label-width="90px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="上级部门">
                          <el-input v-model="parentName" class="input-add" disabled clearable/>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="部门名称" prop="depName">
                            <el-input v-model="departmentForm.depName" class="input-add" placeholder="请输入部门名称" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="部门描述">
                            <el-input v-model="departmentForm.info" class="input-add" type="textarea" placeholder="请输入部门描述" maxlength="150"></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
                <span class="dialog-footer">
                    <el-button @click="onCancel" size="default">取 消</el-button>
                    <el-button type="primary" v-throttle @click="onSubmit(depRef)" size="default">确 定</el-button>
                </span>
            </template>
        </el-dialog>
    </div>
</template>

<script lang="ts">
import { ElMessage } from 'element-plus';
import {reactive, toRefs, onMounted, defineComponent, ref} from 'vue';
import { departmentApi } from '/@/api/systemManage/department';

// 定义接口来定义对象的类型
interface TableDataRow {
    name: string;
    info: string;
    parentId: string;
    id: number;
}
interface DeptState {
    title: string;
    parentName: string
    isShowDialog: boolean;
    departmentForm: {
        depName: string;
        info: string;
        parentId?: null|number
        id?: null|number
    };
    deptData: Array<TableDataRow>;
    depLevelList: Array<Type>;
    depFormRules:{

    }
}
interface Type{
    id:number;
    name:string
}

export default defineComponent({
    name: 'systemAddDept',
    setup(prop, context) {
        const state = reactive<DeptState>({
            title: '',
            parentName: '',
            isShowDialog: false,
            departmentForm: {
                depName: '',
                parentId: null,
                info: '',
                id: null
            },
            deptData: [], // 部门数据
            depLevelList: [
                {id:1,name:'公司'},
                {id:2,name:'事业部'},
                {id:3,name:'车间'},
                {id:4,name:'班组'}
            ], // 部门数据
            depFormRules:{
              depName: [{ required: true, message: '请填写部门名称', trigger: 'blur' }],
            },
        });
        const depRef = ref()
        const findParentById=(tree:Array<any>,id:number|null,depName:string)=>{
          const parent = tree.find(i=>i.id == id)
          if(parent){
            return parent[depName]
          }
          for(const item of tree){
            if(item.children){
              const result = findParentById(item.children,id,depName)
              if(result){
                return result
              }
            }
          }
          return null
        }

        // 打开弹窗
        const openDialog = (type: string, value: any, departmentList: []) => {
            state.isShowDialog = true;
            state.departmentForm = JSON.parse(JSON.stringify(value))
            state.parentName = value.depName
            state.deptData = JSON.parse(JSON.stringify(departmentList));
            if (type === '新增') {
                state.title = '新增部门';
                state.departmentForm = {
                    depName: '',
                    parentId: value.id,
                    info: ''
                };
            } else {
                state.parentName = findParentById(departmentList,value.parentId,'depName')
                state.title = '修改部门';
                state.departmentForm = {
                  depName: value.depName,
                  id: value.id,
                  info: value.info
                }
            }
        };
        // 关闭弹窗
        const closeDialog = () => {
            state.isShowDialog = false;
        };
        // 取消
        const onCancel = () => {
            closeDialog();
        };
        // 新增
        const onSubmit = async () => {
          depRef.value.validate(async (valid:Boolean) => {
            if(valid){
              if (state.title === '新增部门') {
                let res = await departmentApi().addDepartment(state.departmentForm);
                if (res.data.code === 100) {
                  ElMessage({
                    type: 'success',
                    message: '部门新增成功',
                    duration: 2000
                  });
                  closeDialog();
                  context.emit('getDepartmentList');
                } else {
                  ElMessage({
                    type: 'warning',
                    message: res.data.msg
                  });
                }
              } else {
                let res = await departmentApi().modDepartment(state.departmentForm);
                if (res.data.code === 100) {
                  ElMessage({
                    type: 'success',
                    message: '部门修改成功',
                    duration: 2000
                  });
                  closeDialog();
                  context.emit('getDepartmentList');
                } else {
                  ElMessage({
                    type: 'warning',
                    message: res.data.msg
                  });
                }
              }
            }else{
              ElMessage({
                type:'warning',
                message:'请完善基本信息'
              })
            }
          })
        };
        // 初始化部门数据
        const initTableData = () => {};
        // 页面加载时
        onMounted(() => {
            initTableData();
        });
        return {
            depRef,
            findParentById,
            openDialog,
            closeDialog,
            onCancel,
            onSubmit,
            ...toRefs(state)
        };
    }
});
</script>
